@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2007-2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2007-2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "contacteditordialog.h"
@@ -46,13 +33,12 @@ class Q_DECL_HIDDEN ContactEditorDialog::Private
 public:
     Private(ContactEditorDialog::Mode mode, ContactEditorDialog::DisplayMode displaymode, ContactEditor::AbstractContactEditorWidget *editorWidget, ContactEditorDialog *parent)
         : q(parent)
-        , mAddressBookBox(nullptr)
         , mMode(mode)
     {
         QWidget *mainWidget = new QWidget(q);
 
         q->setWindowTitle(mode == ContactEditorDialog::CreateMode ? i18n("New Contact") : i18n("Edit Contact"));
-        QVBoxLayout *mainLayout = new QVBoxLayout(q);
+        auto *mainLayout = new QVBoxLayout(q);
         QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         q->connect(buttonBox, &QDialogButtonBox::accepted, q, [this]() {
             slotOkClicked();
@@ -64,7 +50,7 @@ public:
         mainLayout->addWidget(mainWidget);
         mainLayout->addWidget(buttonBox);
 
-        QGridLayout *layout = new QGridLayout(mainWidget);
+        auto *layout = new QGridLayout(mainWidget);
         layout->setContentsMargins(0, 0, 0, 0);
 
         if (editorWidget) {
@@ -137,7 +123,7 @@ public:
         group.sync();
     }
 
-    ContactEditorDialog *q;
+    ContactEditorDialog *const q;
     CollectionComboBox *mAddressBookBox = nullptr;
     ContactEditorDialog::Mode mMode;
     AkonadiContactEditor *mEditor = nullptr;
