@@ -3,20 +3,7 @@
 
     Copyright (c) 2009 - 2010 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "standardcontactactionmanager.h"
@@ -45,8 +32,6 @@ public:
     Private(KActionCollection *actionCollection, QWidget *parentWidget, StandardContactActionManager *parent)
         : mActionCollection(actionCollection)
         , mParentWidget(parentWidget)
-        , mCollectionSelectionModel(nullptr)
-        , mItemSelectionModel(nullptr)
         , mParent(parent)
     {
         mGenericManager = new StandardActionManager(actionCollection, parentWidget);
@@ -528,14 +513,14 @@ public:
         KMessageBox::error(mParentWidget, i18n("Contact cannot be stored: %1", error), i18n("Failed to store contact"));
     }
 
-    KActionCollection *mActionCollection = nullptr;
-    QWidget *mParentWidget = nullptr;
+    KActionCollection *const mActionCollection;
+    QWidget *const mParentWidget;
     StandardActionManager *mGenericManager = nullptr;
     QItemSelectionModel *mCollectionSelectionModel = nullptr;
     QItemSelectionModel *mItemSelectionModel = nullptr;
     QHash<StandardContactActionManager::Type, QAction *> mActions;
     QSet<StandardContactActionManager::Type> mInterceptedActions;
-    StandardContactActionManager *mParent = nullptr;
+    StandardContactActionManager *const mParent;
 };
 
 StandardContactActionManager::StandardContactActionManager(KActionCollection *actionCollection, QWidget *parent)
