@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (c) 2010 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "standardcontactgroupformatter.h"
@@ -56,7 +43,7 @@ QString StandardContactGroupFormatter::toHtml(HtmlForm form) const
         // we got a contact group with unresolved references -> we have to resolve it ourself
         // this shouldn't be the normal case, actually the calling code should pass in an already resolved
         // contact group
-        ContactGroupExpandJob *job = new ContactGroupExpandJob(group);
+        auto *job = new ContactGroupExpandJob(group);
         if (job->exec()) {
             group.removeAllContactData();
             const KContacts::Addressee::List listContact = job->contacts();
