@@ -1,22 +1,9 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "personaleditorwidget.h"
@@ -36,7 +23,7 @@ using namespace ContactEditor;
 PersonalEditorWidget::PersonalEditorWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QGridLayout *mainLayout = new QGridLayout(this);
+    auto *mainLayout = new QGridLayout(this);
     QLabel *label = new QLabel(i18nc("@label The birthdate of a contact", "Birthdate:"));
     mainLayout->addWidget(label, 0, 0);
 
